@@ -104,11 +104,12 @@ sub choose_videos {
                 $tmp->{$ex}{$video_id}{extractor} = 'youtube';
             }
             $title = check_mapping_stdout( $opt, $title ) if $Encode::Locale::ENCODING_CONSOLE_OUT !~ /^UTF-/i;
-            $has_view_count = 0 if $opt->{list_sort_item} ne 'view_count_raw' && ! $opt->{show_view_count};
             my $line = sprintf "%*s |", $length_video_id, $video_id;
             $line .= sprintf " %7s", $tmp->{$ex}{$video_id}{duration}                          if $has_duration;
             $line .= sprintf "  %*s", $length_upload_date, $tmp->{$ex}{$video_id}{upload_date} if $length_upload_date;
-            $line .= sprintf "  %*s", $length_view_count, $tmp->{$ex}{$video_id}{view_count}   if $has_view_count;
+            if ( ( $opt->{list_sort_item} eq 'view_count_raw' || $opt->{show_view_count} ) && $has_view_count ) {
+                $line .= sprintf "  %*s", $length_view_count, $tmp->{$ex}{$video_id}{view_count};
+            }
             $line .= sprintf "  %s", $title;
             push @videos, $line;
             push @tmp_video_ids, $video_id;
