@@ -6,8 +6,7 @@ use strict;
 use 5.010000;
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( get_yt_list_info get_vimeo_list_info get_new_video_url get_download_info
-                     get_youtube_list_info );
+our @EXPORT_OK = qw( get_vimeo_list_info get_youtube_list_info get_new_video_url get_download_info );
 
 use JSON                qw( decode_json );
 use LWP::UserAgent      qw();
@@ -21,47 +20,9 @@ use App::YTDL::Helper      qw( uni_capture HIDE_CURSOR SHOW_CURSOR );
 
 
 
-sub get_yt_list_info {
-    my ( $opt, $url ) = @_;
-    my $show_progress = 1;
-    my $ua = LWP::UserAgent->new(
-        agent         => $opt->{useragent},
-        timeout       => $opt->{timeout},
-        show_progress => $show_progress
-    );
-    my $tmp;
-    my $count = 0;
-
-    RETRY: while ( 1 ) {
-        $count++;
-        if ( eval {
-            my $res = $ua->get( $url );
-            die $res->status_line, ': ', $url if ! $res->is_success;
-            $tmp = decode_json( $res->decoded_content );
-            die $url . ' - error fetching youtube list info!' if ! defined $tmp || ! %$tmp;
-            1 }
-        ) {
-            return $tmp;
-        }
-        else {
-            say "$count/$opt->{retries}  $@"; #
-            return if $count == $opt->{retries};
-            sleep $opt->{retries} * 3;
-        }
-    }
-}
-
-
 sub get_youtube_list_info {
     my ( $opt, $url ) = @_;
     my $ua = LWP::UserAgent->new(
-    #require File::Spec;
-    #my $tmp_dir = File::Spec->catdir( File::Spec->tmpdir(), 'lwp' );
-    #mkdir $tmp_dir or die $! if ! -d $tmp_dir;
-    #require LWP::UserAgent::Cached;
-    #my $ua = LWP::UserAgent::Cached->new(
-    #    cache_dir     => $tmp_dir,
-
         agent         => $opt->{useragent},
         timeout       => $opt->{timeout},
         show_progress => 1
@@ -87,9 +48,8 @@ sub get_youtube_list_info {
                         my $video_id        = $_->at(  'h3[class="yt-lockup-title"] > a[class]' )->attr( 'href' );
                         my $view_count      = $_->find( 'ul[class="yt-lockup-meta-info"] > li' )->[0]->text;
                         my $upload_date_rel = $_->find( 'ul[class="yt-lockup-meta-info"] > li' )->[1]->text;
-                        $duration =~ s/\.//g; ##
                         $video_id =~ s/^.+=(?=[^=]{11}\z)//;
-                        $view_count =~ s/^(\S+)(?!\S).+\z/$1/; #
+                        $view_count =~ s/^([0-9.,]+).+\z/$1/;
                         $view_count =~ s/[,.]//g;
                         if ( $duration =~ /^(?:\d\d?:){0,2}\d\d?\z/ ) {
                             my $seconds = 0;
