@@ -105,10 +105,11 @@ sub _menus {
             [ '_print_pref_qual', "  Preferred qualities"          ],
         ],
         group_download => [
-            [ 'useragent', "- UserAgent"        ],
-            [ 'overwrite', "- Overwrite"        ],
-            [ 'retries',   "- Download retries" ],
-            [ 'timeout',   "- Timeout"          ],
+            [ 'useragent',      "- UserAgent"        ],
+            [ 'overwrite',      "- Overwrite"        ],
+            [ 'retries',        "- Download retries" ],
+            [ 'timeout',        "- Timeout"          ],
+            [ 'sleep_interval', "- Sleep interval"   ],
         ],
         group_merge => [
             [ 'merge_enabled',   "- Enable Merge"      ],
@@ -361,6 +362,11 @@ sub set_options {
                 my $digits = 3;
                 _opt_number_range( $opt, $choice, $prompt, $digits );
             }
+            elsif ( $choice eq "sleep_interval" ) {
+                my $prompt = 'Seconds to wait between downloads';
+                my $digits = 3;
+                _opt_number_range( $opt, $choice, $prompt, $digits );
+            }
             elsif ( $choice eq "merge_enabled" ) {
                 my $prompt = 'Enable merge';
                 my $list = [ qw( no ask yes ) ];
